@@ -17,7 +17,7 @@ from .default import DefaultClient, DEFAULT_TIMEOUT
 
 
 class ShardClient(DefaultClient):
-    _findhash = re.compile('.*\{(.*)\}.*', re.I)
+    _findhash = re.compile(r'.*\{(.*)\}.*', re.I)
 
     def __init__(self, *args, **kwargs):
         super(ShardClient, self).__init__(*args, **kwargs)
@@ -251,7 +251,7 @@ class ShardClient(DefaultClient):
 
         keys = []
         for server, connection in self._serverdict.items():
-            keys.extend([key for key in connection.scan_iter(**kwargs)])
+            keys.extend(key for key in connection.scan_iter(**kwargs))
 
         res = 0
         if keys:
