@@ -4,7 +4,6 @@ from __future__ import absolute_import, unicode_literals, print_function
 
 import base64
 import unittest
-import sys
 import time
 import datetime
 from datetime import timedelta
@@ -17,9 +16,12 @@ except ImportError:
 from mock import Mock
 
 from django.conf import settings
-from django.core.cache import cache
+from django.core.cache import cache, caches
 from django import VERSION
-from django.test import TestCase
+from django.test import TestCase, override_settings
+from django.test.utils import patch_logger
+from django.utils import six, timezone
+from django.contrib.sessions.backends.cache import SessionStore as CacheSession
 
 import fakeredis
 
@@ -33,17 +35,11 @@ from django_redis.serializers import json as json_serializer
 from django_redis.serializers import msgpack as msgpack_serializer
 
 
-FAKE_REDIS = settings.CACHES["default"]["OPTIONS"].get("REDIS_CLIENT_CLASS") \
-             == "fakeredis.FakeStrictRedis"
+FAKE_REDIS = settings.CACHES["default"]["OPTIONS"].get("REDIS_CLIENT_CLASS") == "fakeredis.FakeStrictRedis"
 
 herd.CACHE_HERD_TIMEOUT = 2
 
-if sys.version_info[0] < 3:
-    text_type = unicode
-    bytes_type = str
-else:
-    text_type = str
-    bytes_type = bytes
+if six.PY3:
     long = int
 
 
@@ -93,11 +89,12 @@ class DjangoRedisCacheTestCustomKeyFunction(TestCase):
         self.assertTrue(bool(res))
 
         keys = self.cache.keys("foo*")
-        self.assertEqual(set(keys), set(["foo-bb", "foo-bc"]))
+        self.assertEqual(set(keys), {"foo-bb", "foo-bc"})
         # ensure our custom function was actually called
         try:
-            self.assertEqual(set(k.decode('utf-8') for k in self.cache.raw_client.keys('*')),
-                set(['#1#foo-bc', '#1#foo-bb']))
+            self.assertEqual(
+                {k.decode('utf-8') for k in self.cache.raw_client.keys('*')},
+                {'#1#foo-bc', '#1#foo-bb'})
         except (NotImplementedError, AttributeError):
             # not all clients support .keys()
             pass
@@ -162,24 +159,24 @@ class DjangoRedisCacheTests(TestCase):
         self.assertEqual(res, 2)
 
     def test_save_string(self):
-        self.cache.set("test_key", "hello"*1000)
+        self.cache.set("test_key", "hello" * 1000)
         res = self.cache.get("test_key")
 
         type(res)
-        self.assertIsInstance(res, text_type)
-        self.assertEqual(res, "hello"*1000)
+        self.assertIsInstance(res, six.text_type)
+        self.assertEqual(res, "hello" * 1000)
 
         self.cache.set("test_key", "2")
         res = self.cache.get("test_key")
 
-        self.assertIsInstance(res, text_type)
+        self.assertIsInstance(res, six.text_type)
         self.assertEqual(res, "2")
 
     def test_save_unicode(self):
         self.cache.set("test_key", "heló")
         res = self.cache.get("test_key")
 
-        self.assertIsInstance(res, text_type)
+        self.assertIsInstance(res, six.text_type)
         self.assertEqual(res, "heló")
 
     def test_save_dict(self):
@@ -189,13 +186,13 @@ class DjangoRedisCacheTests(TestCase):
 
         if isinstance(self.cache.client._serializer,
                       msgpack_serializer.MSGPackSerializer):
-            #MSGPackSerializer serializers use the isoformat for datetimes
-            #https://github.com/msgpack/msgpack-python/issues/12
+            # MSGPackSerializer serializers use the isoformat for datetimes
+            # https://github.com/msgpack/msgpack-python/issues/12
             now_dt = datetime.datetime.now().isoformat()
         else:
             now_dt = datetime.datetime.now()
 
-        test_dict = {"id":1, "date": now_dt, "name": "Foo"}
+        test_dict = {"id": 1, "date": now_dt, "name": "Foo"}
 
         self.cache.set("test_key", test_dict)
         res = self.cache.get("test_key")
@@ -272,7 +269,7 @@ class DjangoRedisCacheTests(TestCase):
         self.cache.set("b", 2)
         self.cache.set("c", 3)
 
-        res = self.cache.get_many(["a","b","c"])
+        res = self.cache.get_many(["a", "b", "c"])
         self.assertEqual(res, {"a": 1, "b": 2, "c": 3})
 
     def test_get_many_unicode(self):
@@ -280,7 +277,7 @@ class DjangoRedisCacheTests(TestCase):
         self.cache.set("b", "2")
         self.cache.set("c", "3")
 
-        res = self.cache.get_many(["a","b","c"])
+        res = self.cache.get_many(["a", "b", "c"])
         self.assertEqual(res, {"a": "1", "b": "2", "c": "3"})
 
     def test_set_many(self):
@@ -301,24 +298,24 @@ class DjangoRedisCacheTests(TestCase):
 
     def test_delete_many(self):
         self.cache.set_many({"a": 1, "b": 2, "c": 3})
-        res = self.cache.delete_many(["a","b"])
+        res = self.cache.delete_many(["a", "b"])
         self.assertTrue(bool(res))
 
         res = self.cache.get_many(["a", "b", "c"])
         self.assertEqual(res, {"c": 3})
 
-        res = self.cache.delete_many(["a","b"])
+        res = self.cache.delete_many(["a", "b"])
         self.assertFalse(bool(res))
 
     def test_delete_many_generator(self):
         self.cache.set_many({"a": 1, "b": 2, "c": 3})
-        res = self.cache.delete_many(key for key in ["a","b"])
+        res = self.cache.delete_many(key for key in ["a", "b"])
         self.assertTrue(bool(res))
 
         res = self.cache.get_many(["a", "b", "c"])
         self.assertEqual(res, {"c": 3})
 
-        res = self.cache.delete_many(["a","b"])
+        res = self.cache.delete_many(["a", "b"])
         self.assertFalse(bool(res))
 
     def test_delete_many_empty_generator(self):
@@ -339,7 +336,7 @@ class DjangoRedisCacheTests(TestCase):
             res = self.cache.get("num")
             self.assertEqual(res, 12)
 
-            #max 64 bit signed int
+            # max 64 bit signed int
             self.cache.set("num", 9223372036854775807)
 
             self.cache.incr("num")
@@ -369,7 +366,6 @@ class DjangoRedisCacheTests(TestCase):
         except NotImplementedError:
             raise unittest.SkipTest("`incr` not supported in herd client")
 
-
     def test_get_set_bool(self):
         self.cache.set("bool", True)
         res = self.cache.get("bool")
@@ -407,7 +403,7 @@ class DjangoRedisCacheTests(TestCase):
             res = self.cache.get("num")
             self.assertEqual(res, 19)
 
-            #max 64 bit signed int + 1
+            # max 64 bit signed int + 1
             self.cache.set("num", 9223372036854775808)
 
             self.cache.decr("num")
@@ -449,7 +445,7 @@ class DjangoRedisCacheTests(TestCase):
         self.assertTrue(bool(res))
 
         keys = self.cache.keys("foo*")
-        self.assertEqual(set(keys), set(["foo-bb", "foo-bc"]))
+        self.assertEqual(set(keys), {"foo-bb", "foo-bc"})
 
         res = self.cache.delete_pattern("*foo-a*")
         self.assertFalse(bool(res))
@@ -557,7 +553,7 @@ class DjangoRedisCacheTests(TestCase):
 
         # Test simple result
         result = set(cache.iter_keys("foo*"))
-        self.assertEqual(result, set(["foo1", "foo2", "foo3"]))
+        self.assertEqual(result, {"foo1", "foo2", "foo3"})
 
         # Test limited result
         result = list(cache.iter_keys("foo*", itersize=2))
@@ -571,7 +567,7 @@ class DjangoRedisCacheTests(TestCase):
         try:
             cache = caches["sample"]
             client = cache.client
-            client._server = ["foo", "bar",]
+            client._server = ["foo", "bar"]
             client._clients = ["Foo", "Bar"]
 
             self.assertEqual(client.get_client(write=True), "Foo")
@@ -583,9 +579,6 @@ class DjangoRedisCacheTests(TestCase):
         pass
 
 
-import django_redis.cache
-
-
 class DjangoOmitExceptionsTests(TestCase):
     def setUp(self):
         self._orig_setting = django_redis.cache.DJANGO_REDIS_IGNORE_EXCEPTIONS
@@ -607,17 +600,6 @@ class DjangoOmitExceptionsTests(TestCase):
         self.assertEqual(self.cache.get("key", default="default"), "default")
 
 
-from django.contrib.sessions.backends.cache import SessionStore as CacheSession
-
-from django.contrib.sessions.serializers import (
-    JSONSerializer, PickleSerializer,
-)
-from django.core import management
-from django.core.cache import caches
-from django.test import override_settings
-from django.test.utils import patch_logger
-from django.utils import six, timezone
-
 class SessionTestsMixin(object):
     # This does not inherit from TestCase to avoid any tests being run with this
     # class, which wouldn't work, and to allow different TestCase subclasses to
