@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 
-import os, sys
+import os
+import sys
+
 sys.path.insert(0, '..')
 os.environ.setdefault("DJANGO_SETTINGS_MODULE", "test_sqlite_sharding")
 
