@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 
-import os, sys
+import os
+import sys
+
 os.environ.setdefault("DJANGO_SETTINGS_MODULE", "test_sqlite_usock")
 sys.path.insert(0, 'tests')
 
